from django.http.response import HttpResponseRedirect
from django.conf import settings

from tradenity import Configuration
from tradenity.exceptions import SessionExpiredException


def reset_session():
    Configuration.AUTH_TOKEN_HOLDER.reset()
    return HttpResponseRedirect("/")


class SessionExpiryHandlerMiddleware(object):

    def process_exception(self, request, exception):
        if isinstance(exception, SessionExpiredException):
            if hasattr(settings, 'on_session_expiry') and callable(settings.on_session_expiry):
                return settings.on_session_expiry()
            else:
                return reset_session()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_python_sdk
----------------------------------

Tests for `python_sdk` module.
"""

import unittest

import tradenity


class TestPython_sdk(unittest.TestCase):

    def setUp(self):
        pass

    def test_something(self):
        assert(tradenity.__version__)

    def tearDown(self):
        pass



from tradenity.token_holder import AuthTokenHolder
from tradenity_django.sdk.ext.middleware import CurrentRequestMiddleware


class DjangoAuthTokenHolder(AuthTokenHolder):
    AUTH_TOKEN_NAME = 'tradenity_auth_token'

    def __init__(self):
        super(DjangoAuthTokenHolder, self).__init__()
        self._token = None

    @property
    def token(self):
        session = CurrentRequestMiddleware.get_request().session
        return session.get(self.AUTH_TOKEN_NAME, None)

    @token.setter
    def token(self, value):
        session = CurrentRequestMiddleware.get_request().session
        session[self.AUTH_TOKEN_NAME] = value

    def reset(self):
        session = CurrentRequestMiddleware.get_request().session
        del session[self.AUTH_TOKEN_NAME]



"""A setuptools based setup module for python-sdk"""
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from codecs import open
from os import path
from setuptools import setup, find_packages

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as readme_file:
    readme = readme_file.read()

with open(path.join(here, 'HISTORY.rst'), encoding='utf-8') as history_file:
    history = history_file.read().replace('.. :changelog:', '')

requirements = [
    'tradenity'
]

test_requirements = [
]

setup(
    name='tradenity-django-ext',
    version='0.7.0',
    description="Django extensions for Tradenity Python SDK",
    long_description=readme + '\n\n' + history,
    author="Joseph Fouad",
    author_email='tradenity@tradenity.com',
    url='https://github.com/tradenity/python-sdk-django-ext',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    entry_points={
        'console_scripts': [],
        },
    include_package_data=True,
    install_requires=requirements,
    license="APACHE",
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
    ],
    test_suite='tests',
    tests_require=test_requirements,
)
